@@ -10,17 +10,14 @@ use constant abstract => 'split runlist yaml files';
 
 sub opt_spec {
     return (
-        [   "outdir|o=s", "output location, [stdout] for screen, default is [.]", { default => '.' }
-        ],
-        [ "suffix|s=s", "extension of output files, default is [.yml]", { default => '.yml' } ],
+        [ "outdir|o=s", "output location, [stdout] for screen", { default => '.' } ],
+        [ "suffix|s=s", "extension of output files,",           { default => '.yml' } ],
+        { show_defaults => 1, }
     );
 }
 
 sub usage_desc {
-    my $self = shift;
-    my $desc = $self->SUPER::usage_desc;    # "%c COMMAND %o"
-    $desc .= " <infile>";
-    return $desc;
+    return "runlist split [options] <infile>";
 }
 
 sub description {
@@ -33,7 +30,10 @@ sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
     if ( @{$args} != 1 ) {
-        $self->usage_error("This command need one input file.");
+        my $message = "This command need one input file.\n\tIt found";
+        $message .= sprintf " [%s]", $_ for @{$args};
+        $message .= ".\n";
+        $self->usage_error($message);
     }
     for ( @{$args} ) {
         next if lc $_ eq "stdin";
